"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Failbot = void 0;
class Failbot {
    constructor(opts) {
        const { app, catalogService, backends } = opts;
        this.app = app;
        this.catalogService = catalogService;
        this.backends = backends;
    }
    /**
     * Populate default context from settings. Since settings commonly comes from
     * ENV, this allows setting defaults for the context via the environment.
     */
    getFailbotContext() {
        const failbotKeys = {};
        if (typeof process !== 'undefined') {
            for (const key in process.env) {
                if (key.startsWith('FAILBOT_CONTEXT_')) {
                    const formattedKey = key.replace(/^FAILBOT_CONTEXT_/, '').toLowerCase();
                    failbotKeys[formattedKey] = process.env[key];
                }
                if (key === 'OTEL_SERVICE_NAME') {
                    failbotKeys['catalog_service'] = process.env[key];
                }
            }
        }
        return failbotKeys;
    }
    report(error, metadata) {
        const envContext = this.getFailbotContext();
        const data = Object.assign({ app: this.app }, envContext, { catalog_service: this.catalogService || envContext.catalog_service }, metadata);
        return this.backends.map(backend => backend.report(error, data));
    }
}
exports.Failbot = Failbot;
//# sourceMappingURL=failbot.js.map